clear 
clear matrix
capture log close
log using "CWrevision.log", replace

********************************************************************************
********************************************************************************
* PROJECT: Hiding Human Rights Violations in Response to UN Naming and Shaming *
* AUTHOR: Demeritt & Monroe						                               *
* CREATED ON: 19 Nov 2018										           	   *
* LAST EDITED ON: 25 March 2019										           *
********************************************************************************
********************************************************************************

set seed 08221981
set more off
use "N&Smaster.v2.dta"
tsset ccode year

quietly{
* Invert needed CIRI variables (so that higher values --> more abuse):
recode kill 0=2 1=1 2=0
replace kill=. if kill<0
tab kill

recode tort 0=2 1=1 2=0
replace tort=. if tort<0
tab tort

recode polpris 0=2 1=1 2=0
replace polpris=. if polpris<0
tab polpris

recode disap 0=2 1=1 2=0
replace disap=. if disap<0
tab disap

* Generate binary variables for shaming events (=1 if some, =0 if none):
gen shamekillbin=.
replace shamekillbin=0 if shame_kill==0
replace shamekillbin=1 if shame_kill>0
replace shamekillbin=. if shame_kill==.

gen shametortbin=.
replace shametortbin=0 if shame_tort==0
replace shametortbin=1 if shame_tort>0
replace shametortbin=. if shame_tort==.

gen shameprisbin=.
replace shameprisbin=0 if shame_impris==0
replace shameprisbin=1 if shame_impris>0
replace shameprisbin=. if shame_impris==.

gen shamedisbin=.
replace shamedisbin=0 if shame_disap==0
replace shamedisbin=1 if shame_disap>0
replace shamedisbin=. if shame_disap==.

*Generate linear & polynomial time counters:
*egen time = group(year)
gen time2=time*time
}
quietly{
***************************************************************************
**GENERATE VARIABLES TO TEST SUBSTITUTION: 
**Does shamed tactic decrease and other tactic(s) increase?
***************************************************************************

***generate dynamic CIRI variables:

*(1) lag each CIRI tactic 1 period
gen l1ccode=l1.ccode
gen l1kill=l1.kill
gen l1tort=l1.tort
gen l1disap=l1.disap
gen l1polpris=l1.polpris

*(2) take the first difference from t-1 to t:
gen diffkill=kill-l1.kill
gen difftort=tort-l1.tort
gen diffdisap=disap-l1.disap
gen diffpolpris=polpris-l1.polpris
*** In these variables, positive values indicated worsening performance from last year to this year,
*** to this year, while values = 0 indicate no change, and 
*** values < 0 indicate improved performance.

***Killing:

****** Killing better and torture worse?
gen kill_subs_tort=0
replace kill_subs_tort=1 if diffkill<0 & difftort>0
replace kill_subs_tort=. if diffkill==. | difftort==.

****** Killing better and disap worse?
gen kill_subs_disap=0
replace kill_subs_disap=1 if diffkill<0 & diffdisap>0
replace kill_subs_disap=. if diffkill==. | diffdisap==.

****** Killing better and polpris worse?

gen kill_subs_pris=0
replace kill_subs_pris=1 if diffkill<0 & diffpolpris>0
replace kill_subs_pris=. if diffkill==. | diffpolpris==.

***Torture:

****** Torture better and killing worse?

gen tort_subs_kill=0
replace tort_subs_kill=1 if difftort<0 & diffkill>0
replace tort_subs_kill=. if difftort==. | diffkill==.

****** Torture better and disap worse?

gen tort_subs_disap=0
replace tort_subs_disap=1 if difftort<0 & diffdisap>0
replace tort_subs_disap=. if difftort==. | diffdisap==.

****** Torture better and polpris worse?
gen tort_subs_pris=0
replace tort_subs_pris=1 if difftort<0 & diffpolpris>0
replace tort_subs_pris=. if difftort==. | diffpolpris==.

***Disappearance:

****** Disappearance better and killing worse?
gen dis_subs_kill=0
replace dis_subs_kill=1 if diffdisap<0 & diffkill>0
replace dis_subs_kill=. if diffdisap==. | diffkill==.

****** Disappearance better and torture worse?
gen dis_subs_tort=0
replace dis_subs_tort=1 if diffdisap<0 & difftort>0
replace dis_subs_tort=. if diffdisap==. | difftort==.

****** Disappearance better and polpris worse?
gen dis_subs_pris=0
replace dis_subs_pris=1 if diffdisap<0 & diffpolpris>0
replace dis_subs_pris=. if diffdisap==. | diffpolpris==.

***Imprisonment:

****** Imprisonment better and killing worse?
gen pris_subs_kill=0
replace pris_subs_kill=1 if diffpolpris<0 & diffkill>0
replace pris_subs_kill=. if diffpolpris==. | diffkill==.

****** Imprisonment better and torture worse?
gen pris_subs_tort=0
replace pris_subs_tort=1 if diffpolpris<0 & difftort>0
replace pris_subs_tort=. if diffpolpris==. | difftort==.

****** Imprisonment better and disap worse?
gen pris_subs_dis=0
replace pris_subs_dis=1 if diffpolpris<0 & diffdisap>0
replace pris_subs_dis=. if diffpolpris==. | diffdisap==.

**********************************
*** Combining response tactics ***
**********************************

*** Killing
gen kill_subs=0
replace kill_subs=1 if kill_subs_tort==1 | kill_subs_pris==1 | kill_subs_dis==1
replace kill_subs=. if kill_subs_tort==. & kill_subs_pris==. & kill_subs_dis==.

*** Torture
gen tort_subs=0
replace tort_subs=1 if tort_subs_kill==1 | tort_subs_pris==1 | tort_subs_dis==1
replace tort_subs=. if tort_subs_kill==. & tort_subs_pris==. & tort_subs_dis==.

*** Disappearances
gen dis_subs=0
replace dis_subs=1 if dis_subs_kill==1 | dis_subs_pris==1 | dis_subs_tort==1
replace dis_subs=. if dis_subs_kill==. & dis_subs_pris==. & dis_subs_tort==.

*** Imprisonment
gen pris_subs=0
replace pris_subs=1 if pris_subs_kill==1 | pris_subs_dis==1 | pris_subs_tort==1
replace pris_subs=. if pris_subs_kill==. & pris_subs_dis==. & pris_subs_tort==.


/*
***************************************************************************
**GENERATE VARIABLES TO TEST STRATEGIC MANIPULATION: 
**Does shamed tactic stay steady and other tactic(s) increase?
***************************************************************************

***Killing:

****** Killing steady and torture worse?
gen sm_kill_tort=0
replace sm_kill_tort=1 if diffkill==0 & difftort>0
replace sm_kill_tort=. if diffkill==.

****** Killing steady and disap worse?
gen sm_kill_dis=0
replace sm_kill_dis=1 if diffkill==0 & diffdisap>0
replace sm_kill_dis=. if diffkill==.

****** Killing steady and polpris worse?
gen sm_kill_pris=0
replace sm_kill_pris=1 if diffkill==0 & diffpolpris>0
replace sm_kill_pris=. if diffkill==.


***Torture:

****** Torture steady and killing worse?
gen sm_tort_kill=0
replace sm_tort_kill=1 if difftort==0 & diffkill>0
replace sm_tort_kill=. if difftort==.

****** Torture steady and disap worse?
gen sm_tort_disap=0
replace sm_tort_disap=1 if difftort==0 & diffdisap>0
replace sm_tort_disap=. if difftort==.

****** Torture steady and polpris worse?
gen sm_tort_pris=0
replace sm_tort_pris=1 if difftort==0 & diffpolpris>0
replace sm_tort_pris=. if difftort==.

***Disappearance:

****** Disappearance steady and killing worse?
gen sm_dis_kill=0
replace sm_dis_kill=1 if diffdisap==0 & diffkill>0
replace sm_dis_kill=. if diffdisap==.

****** Disappearance steady and torture worse?
gen sm_dis_tort=0
replace sm_dis_tort=1 if diffdisap==0 & difftort>0
replace sm_dis_tort=. if diffdisap==.

****** Disappearance steady and polpris worse?
gen sm_dis_pris=0
replace sm_dis_pris=1 if diffdisap==0 & diffpolpris>0
replace sm_dis_pris=. if diffdisap==.

***Imprisonment:

****** Imprisonment steady and killing worse?
gen sm_pris_kill=0
replace sm_pris_kill=1 if diffpolpris==0 & diffkill>0
replace sm_pris_kill=. if diffpolpris==.

****** Imprisonment steady and torture worse?
gen sm_pris_tort=0
replace sm_pris_tort=1 if diffpolpris==0 & difftort>0
replace sm_pris_tort=. if diffpolpris==.

****** Imprisonment steady and disap worse?
gen sm_pris_dis=0
replace sm_pris_dis=1 if diffpolpris==0 & diffdisap>0
replace sm_pris_dis=. if diffpolpris==.

***************************************************************************
**GENERATE 2ND SET OF VARIABLES TO TEST STRATEGIC MANIPULATION: 
**Does shamed tactic increase and other tactic(s) also increase?
***************************************************************************

***Killing:

****** Killing worse and torture worse?
gen sm2_kill_tort=0
replace sm2_kill_tort=1 if diffkill>0 & difftort>0
replace sm2_kill_tort=. if diffkill==.

****** Killing worse and disap worse?
gen sm2_kill_dis=0
replace sm2_kill_dis=1 if diffkill>0 & diffdisap>0
replace sm2_kill_dis=. if diffkill==.

****** Killing worse and polpris worse?
gen sm2_kill_pris=0
replace sm2_kill_pris=1 if diffkill>0 & diffpolpris>0
replace sm2_kill_pris=. if diffkill==.

***Torture:

****** Torture worse and killing worse?
gen sm2_tort_kill=0
replace sm2_tort_kill=1 if difftort>0 & diffkill>0
replace sm2_tort_kill=. if difftort==.

****** Torture worse and disap worse?
gen sm2_tort_dis=0
replace sm2_tort_dis=1 if difftort>0 & diffdisap>0
replace sm2_tort_dis=. if difftort==.

****** Torture worse and polpris worse?
gen sm2_tort_pris=0
replace sm2_tort_pris=1 if difftort>0 & diffpolpris>0
replace sm2_tort_pris=. if difftort==.

***Disappearance:

****** Disappearance worse and killing worse?
gen sm2_dis_kill=0
replace sm2_dis_kill=1 if diffdisap>0 & diffkill>0
replace sm2_dis_kill=. if diffdisap==.

****** Disappearance worse and torture worse?
gen sm2_dis_tort=0
replace sm2_dis_tort=1 if diffdisap>0 & difftort>0
replace sm2_dis_tort=. if diffdisap==.

****** Disappearance worse and polpris worse?
gen sm2_dis_pris=0
replace sm2_dis_pris=1 if diffdisap>0 & diffpolpris>0
replace sm2_dis_pris=. if diffdisap==.

***Imprisonment:

****** Imprisonment worse and killing worse?
gen sm2_pris_kill=0
replace sm2_pris_kill=1 if diffpolpris>0 & diffkill>0
replace sm2_pris_kill=. if diffpolpris==.

****** Imprisonment worse and torture worse?
gen sm2_pris_tort=0
replace sm2_pris_tort=1 if diffpolpris>0 & difftort>0
replace sm2_pris_tort=. if diffpolpris==.

****** Imprisonment worse and disap worse?
gen sm2_pris_dis=0
replace sm2_pris_dis=1 if diffpolpris>0& diffdisap>0
replace sm2_pris_dis=. if diffpolpris==.

***************************************************************************
**genERATE 3RD SET OF VARIABLES TO TEST STRATEGIC MANIPULATION: 
**Does shamed tactic increase or stay steady and other tactic(s) increase?
***************************************************************************

***Killing:

****** Killing steady or worse and torture worse?
gen sm3_kill_tort=0
replace sm3_kill_tort=1 if diffkill>=0 & difftort>0
replace sm3_kill_tort=. if diffkill==.

****** Killing steady or worse and disap worse?
gen sm3_kill_dis=0
replace sm3_kill_dis=1 if diffkill>=0 & diffdisap>0
replace sm3_kill_dis=. if diffkill==.

****** Killing steady or worse and polpris worse?
gen sm3_kill_pris=0
replace sm3_kill_pris=1 if diffkill>=0 & diffpolpris>0
replace sm3_kill_pris=. if diffkill==.

***Torture:

****** Torture steady or worse and killing worse?
gen sm3_tort_kill=0
replace sm3_tort_kill=1 if difftort>=0 & diffkill>0
replace sm3_tort_kill=. if difftort==.

****** Torture steady or worse and disap worse?
gen sm3_tort_dis=0
replace sm3_tort_dis=1 if difftort>=0 & diffdisap>0
replace sm3_tort_dis=. if difftort==.

****** Torture steady or worse and polpris worse?
gen sm3_tort_pris=0
replace sm3_tort_pris=1 if difftort>=0 & diffpolpris>0
replace sm3_tort_pris=. if difftort==.

***Disappearance:

****** Disappearance steady or worse and killing worse?
gen sm3_dis_kill=0
replace sm3_dis_kill=1 if diffdis>=0 & diffkill>0
replace sm3_dis_kill=. if diffdisap==.

****** Disappearance steady or worse and torture worse?
gen sm3_dis_tort=0
replace sm3_dis_tort=1 if diffdis>=0 & difftort==0
replace sm3_dis_tort=. if diffdisap==.

****** Disappearance steady or worse and polpris worse?
gen sm3_dis_pris=0
replace sm3_dis_pris=1 if diffdis>=0 & diffpolpris>0
replace sm3_dis_pris=. if diffdisap==.

***Imprisonment:

****** Imprisonment steady or worse and killing worse?
gen sm3_pris_kill=0
replace sm3_pris_kill=1 if diffpolpris>=0 & diffkill>0
replace sm3_pris_kill=. if diffpolpris==.

****** Imprisonment steady or worse and torture worse?
gen sm3_pris_tort=0
replace sm3_pris_tort=1 if diffpolpris>=0 & difftort>0
replace sm3_pris_tort=. if diffpolpris==.

****** Imprisonment steady or worse and disap worse?
gen sm3_pris_dis=0
replace sm3_pris_dis=1 if diffpolpris>=0 & diffdisap>0
replace sm3_pris_dis=. if diffpolpris==.

*/


* generate other necessary lags and transformations:
replace democ=. if democ<0
replace autoc=. if autoc<0
*gen polity2sq=polity2*polity2
gen l1polity2sq=l1.polity2sq
gen l1polity2=l1.polity2
gen lnpop=ln(pop)
gen l1lnpop=l1.lnpop
gen lngdp=ln(gdp)
gen l1lngdp=l1.lngdp
gen l1priowar=l1.priowar
}

******probit models******
set more off

quietly{
****NAIVE MODELS (NO CONTROLS)****

**TESTING SUBSTITUTION:
probit F.kill_subs  shame_killing  , cluster(ccode) nolog
probit F.tort_subs shame_tort  , cluster(ccode) nolog
probit F.dis_subs shame_disapp  , cluster(ccode) nolog
probit F.pris_subs shame_impris  , cluster(ccode) nolog


/*
**TESTING STRATEGIC MANIPULATION:
probit F.kill_sm  shame_killing  , cluster(ccode) nolog
probit F.tort_sm shame_tort  , cluster(ccode) nolog
probit F.dis_sm shame_disapp  , cluster(ccode) nolog
probit F.pris_sm shame_impris  , cluster(ccode) nolog
*/
}
****FULL MODELS (Table 1)****

probit F.kill_subs   shame_killing   polity2 polity2sq priowar lnpop time time2, cluster(ccode) nolog
probit F.tort_subs shame_tort  polity2  polity2sq priowar  lnpop time time2, cluster(ccode) nolog
probit F.dis_subs shame_disapp  polity2 polity2sq   priowar lnpop time time2, cluster(ccode) nolog
probit F.pris_subs shame_impris  polity2  polity2sq   priowar lnpop time time2, cluster(ccode) nolog

quietly{
***** IN-SAMPLE DESCRIPTIVES -- 

**TABBING SUBSTITUTION VARIABLES:
tab kill_subs if e(sample)==1
tab tort_subs if e(sample)==1
tab dis_subs if e(sample)==1
tab pris_subs if e(sample)==1


/*

**TABBING STRAT. MANIP. VARIABLES:
tab kill_sm if e(sample)==1
tab tort_sm if e(sample)==1
tab dis_sm if e(sample)==1
tab pris_sm if e(sample)==1
*/



/*
**TESTING STRATEGIC MANIPULATION:
probit F.kill_sm shame_killing  polity2  polity2sq priowar  , cluster(ccode) nolog
probit F.tort_sm shame_tort  polity2  polity2sq  priowar  , cluster(ccode) nolog
probit F.dis_sm shame_disapp  polity2 polity2sq  priowar  , cluster(ccode) nolog
probit F.pris_sm shame_impris  polity2  polity2sq  priowar   , cluster(ccode) nolog
*/
}

****** SUBSTANTIVE EFFECTS *******

** ... of shaming for killing:

quietly{ 
#delimit ; 

quietly probit F.kill_subs   shame_killing   polity2 polity2sq priowar lnpop time time2
	, cluster(ccode) nolog;

preserve;
tabstat shame_kill polity2 polity2sq priowar lnpop time time2 if e(sample)==1, statistic(mean median);
  
  
*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_KILL=0                  *;
*     ****************************************************************  *;

set seed 10101;

drawnorm JR_b1-JR_b8, n(10000) means(e(b)) cov(e(V)) clear;
save simulated_betas, replace;
restore;
merge using simulated_betas;
summarize _merge;
drop _merge;

scalar h_shame_kill=0;
scalar h_polity2=16;
scalar h_polity2sq=256;
scalar h_priowar=0;
scalar h_lnpop= 9.08;
scalar h_time= 54;
scalar h_time2= 2916;
scalar h_constant=1;

generate x_betahat0  = JR_b1*h_shame_kill + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat0=normal(x_betahat0);
sum prob_hat0;
centile prob_hat0, centile(5, 95);

*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_KILL=1                  *;
*     ****************************************************************  *;
scalar h_shame_kill=1;
generate x_betahat1  = JR_b1*h_shame_kill + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat1=normal(x_betahat1);
sum prob_hat1;
centile prob_hat1, centile(5, 95);

*     ****************************************************************  *;
*       Calculate change in PR(SUBSTITUTION=1) when SHAME INCREASES     *;
*       FROM 0 to 1                                                     *;
*     ****************************************************************  *;
gen diff = prob_hat1-prob_hat0;
};

sum diff;
centile diff, centile(5,95);

** ... of shaming for torture;
quietly{;
drop JR_b* x_betahat0 x_betahat1 prob_hat0 prob_hat1 diff;
sort ccode year;
quietly probit F.tort_subs shame_tort  polity2  polity2sq priowar  lnpop time time2
	, cluster(ccode) nolog;
preserve;
  
 
*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_TORT=0                  *;
*     ****************************************************************  *;

set seed 10101;

drawnorm JR_b1-JR_b8, n(10000) means(e(b)) cov(e(V)) clear;
save simulated_betas, replace;
restore;
merge using simulated_betas;
summarize _merge;
drop _merge;

scalar h_shame_tort=0;
scalar h_polity2=16;
scalar h_polity2sq=256;
scalar h_priowar=0;
scalar h_lnpop= 9.08;
scalar h_time= 54;
scalar h_time2= 2916;
scalar h_constant=1;

generate x_betahat0  = JR_b1*h_shame_tort + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat0=normal(x_betahat0);
sum prob_hat0;
centile prob_hat0, centile(5, 95);

*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_TORT=1                  *;
*     ****************************************************************  *;
scalar h_shame_tort=1;
generate x_betahat1  = JR_b1*h_shame_tort + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat1=normal(x_betahat1);
sum prob_hat1;
centile prob_hat1, centile(5, 95);

*     ****************************************************************  *;
*       Calculate change in PR(SUBSTITUTION=1) when SHAME INCREASES     *;
*       FROM 0 to 1                                                     *;
*     ****************************************************************  *;
gen diff = prob_hat1-prob_hat0;
};

sum diff;
centile diff, centile(5,95);


** ... of shaming for disappearances;
quietly{;
drop JR_b* x_betahat0 x_betahat1 prob_hat0 prob_hat1 diff;
sort ccode year;
quietly probit F.dis_subs shame_disapp  polity2 polity2sq   priowar lnpop time time2
	, cluster(ccode) nolog;
preserve;
   
*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_DIS=0                  *;
*     ****************************************************************  *;

set seed 10101;

drawnorm JR_b1-JR_b8, n(10000) means(e(b)) cov(e(V)) clear;
save simulated_betas, replace;
restore;
merge using simulated_betas;
summarize _merge;
drop _merge;

scalar h_shame_dis=0;
scalar h_polity2=16;
scalar h_polity2sq=256;
scalar h_priowar=0;
scalar h_lnpop= 9.08;
scalar h_time= 54;
scalar h_time2= 2916;
scalar h_constant=1;

generate x_betahat0  = JR_b1*h_shame_dis + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat0=normal(x_betahat0);
sum prob_hat0;
centile prob_hat0, centile(5, 95);

*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_dis=1                  *;
*     ****************************************************************  *;
scalar h_shame_dis=1;
generate x_betahat1  = JR_b1*h_shame_dis + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat1=normal(x_betahat1);
sum prob_hat1;
centile prob_hat1, centile(5, 95);

*     ****************************************************************  *;
*       Calculate change in PR(SUBSTITUTION=1) when SHAME INCREASES     *;
*       FROM 0 to 1                                                     *;
*     ****************************************************************  *;
gen diff = prob_hat1-prob_hat0;

};

sum diff;
centile diff, centile(5,95);

** ... of shaming for pol. imprisonment;
quietly{;
drop JR_b* x_betahat0 x_betahat1 prob_hat0 prob_hat1 diff;
sort ccode year;
quietly probit F.pris_subs shame_impris  polity2  polity2sq   priowar lnpop time time2
	, cluster(ccode) nolog;
preserve;
   
*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_IMPR=0                  *;
*     ****************************************************************  *;

set seed 10101;

drawnorm JR_b1-JR_b8, n(10000) means(e(b)) cov(e(V)) clear;
save simulated_betas, replace;
restore;
merge using simulated_betas;
summarize _merge;
drop _merge;

scalar h_shame_impris=0;
scalar h_polity2=16;
scalar h_polity2sq=256;
scalar h_priowar=0;
scalar h_lnpop= 9.08;
scalar h_time= 54;
scalar h_time2= 2916;
scalar h_constant=1;

generate x_betahat0  = JR_b1*h_shame_impris + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat0=normal(x_betahat0);
sum prob_hat0;
centile prob_hat0, centile(5, 95);

*     ****************************************************************  *;
*       Calculate PR(SUBSTITUTION=1) when SHAME_TORT=1                  *;
*     ****************************************************************  *;
scalar h_shame_impris=1;
generate x_betahat1  = JR_b1*h_shame_impris + JR_b2*h_polity2 + JR_b3*h_polity2sq
    + JR_b4*h_priowar + JR_b5*h_lnpop + JR_b6*h_time + JR_b7*h_time2
	+ JR_b8*h_constant;
generate prob_hat1=normal(x_betahat1);
sum prob_hat1;
centile prob_hat1, centile(5, 95);

*     ****************************************************************  *;
*       Calculate change in PR(SUBSTITUTION=1) when SHAME INCREASES     *;
*       FROM 0 to 1                                                     *;
*     ****************************************************************  *;
gen diff = prob_hat1-prob_hat0;
};

sum diff;
centile diff, centile(5,95);


****** Generate figure;
#delimit cr
clear
use substantive2.dta
graph box fd, over(shame) ytitle("First Difference in Pr(Substitution)") 
graph export "substitution.pdf", replace

****************************************
**** ROBUSTNESS CHECKS for appendix ****
****************************************

quietly{
clear
set seed 08221981
set more off
use "N&Smaster.v2.dta"
tsset ccode year

* Invert needed CIRI variables (so that higher values --> more abuse):
recode kill 0=2 1=1 2=0
replace kill=. if kill<0
tab kill

recode tort 0=2 1=1 2=0
replace tort=. if tort<0
tab tort

recode polpris 0=2 1=1 2=0
replace polpris=. if polpris<0
tab polpris

recode disap 0=2 1=1 2=0
replace disap=. if disap<0
tab disap

* Generate binary variables for shaming events (=1 if some, =0 if none):
gen shamekillbin=.
replace shamekillbin=0 if shame_kill==0
replace shamekillbin=1 if shame_kill>0
replace shamekillbin=. if shame_kill==.

gen shametortbin=.
replace shametortbin=0 if shame_tort==0
replace shametortbin=1 if shame_tort>0
replace shametortbin=. if shame_tort==.

gen shameprisbin=.
replace shameprisbin=0 if shame_impris==0
replace shameprisbin=1 if shame_impris>0
replace shameprisbin=. if shame_impris==.

gen shamedisbin=.
replace shamedisbin=0 if shame_disap==0
replace shamedisbin=1 if shame_disap>0
replace shamedisbin=. if shame_disap==.

gen time2=time*time

***************************************************************************
**GENERATE VARIABLES TO TEST SUBSTITUTION: 
**Does shamed tactic decrease and other tactic(s) increase?
***************************************************************************

***generate dynamic CIRI variables:

*(1) lag each CIRI tactic 1 period
gen l1ccode=l1.ccode
gen l1kill=l1.kill
gen l1tort=l1.tort
gen l1disap=l1.disap
gen l1polpris=l1.polpris

*(2) take the first difference from t-1 to t:
gen diffkill=kill-l1kill
gen difftort=tort-l1tort
gen diffdisap=disap-l1disap
gen diffpolpris=polpris-l1polpris
*** In these variables, positive values indicated worsening performance from last year to this year,
*** to this year, while values = 0 indicate no change, and 
*** values < 0 indicate improved performance.

***Killing:

****** Killing better and torture worse?
gen kill_subs_tort=0
replace kill_subs_tort=1 if diffkill<0 & difftort>0
replace kill_subs_tort=. if diffkill==. | difftort==.

****** Killing better and disap worse?
gen kill_subs_disap=0
replace kill_subs_disap=1 if diffkill<0 & diffdisap>0
replace kill_subs_disap=. if diffkill==. | diffdisap==.

****** Killing better and polpris worse?

gen kill_subs_pris=0
replace kill_subs_pris=1 if diffkill<0 & diffpolpris>0
replace kill_subs_pris=. if diffkill==. | diffpolpris==.

***Torture:

****** Torture better and killing worse?

gen tort_subs_kill=0
replace tort_subs_kill=1 if difftort<0 & diffkill>0
replace tort_subs_kill=. if difftort==. | diffkill==.

****** Torture better and disap worse?

gen tort_subs_disap=0
replace tort_subs_disap=1 if difftort<0 & diffdisap>0
replace tort_subs_disap=. if difftort==. | diffdisap==.

****** Torture better and polpris worse?
gen tort_subs_pris=0
replace tort_subs_pris=1 if difftort<0 & diffpolpris>0
replace tort_subs_pris=. if difftort==. | diffpolpris==.

***Disappearance:

****** Disappearance better and killing worse?
gen dis_subs_kill=0
replace dis_subs_kill=1 if diffdisap<0 & diffkill>0
replace dis_subs_kill=. if diffdisap==. | diffkill==.

****** Disappearance better and torture worse?
gen dis_subs_tort=0
replace dis_subs_tort=1 if diffdisap<0 & difftort>0
replace dis_subs_tort=. if diffdisap==. | difftort==.

****** Disappearance better and polpris worse?
gen dis_subs_pris=0
replace dis_subs_pris=1 if diffdisap<0 & diffpolpris>0
replace dis_subs_pris=. if diffdisap==. | diffpolpris==.

***Imprisonment:

****** Imprisonment better and killing worse?
gen pris_subs_kill=0
replace pris_subs_kill=1 if diffpolpris<0 & diffkill>0
replace pris_subs_kill=. if diffpolpris==. | diffkill==.

****** Imprisonment better and torture worse?
gen pris_subs_tort=0
replace pris_subs_tort=1 if diffpolpris<0 & difftort>0
replace pris_subs_tort=. if diffpolpris==. | difftort==.

****** Imprisonment better and disap worse?
gen pris_subs_dis=0
replace pris_subs_dis=1 if diffpolpris<0 & diffdisap>0
replace pris_subs_dis=. if diffpolpris==. | diffdisap==.

**********************************
*** Combining response tactics ***
**********************************

*** Killing
gen kill_subs=0
replace kill_subs=1 if kill_subs_tort==1 | kill_subs_pris==1 | kill_subs_dis==1
replace kill_subs=. if kill_subs_tort==. & kill_subs_pris==. & kill_subs_dis==.

*** Torture
gen tort_subs=0
replace tort_subs=1 if tort_subs_kill==1 | tort_subs_pris==1 | tort_subs_dis==1
replace tort_subs=. if tort_subs_kill==. & tort_subs_pris==. & tort_subs_dis==.

*** Disappearances
gen dis_subs=0
replace dis_subs=1 if dis_subs_kill==1 | dis_subs_pris==1 | dis_subs_tort==1
replace dis_subs=. if dis_subs_kill==. & dis_subs_pris==. & dis_subs_tort==.

*** Imprisonment
gen pris_subs=0
replace pris_subs=1 if pris_subs_kill==1 | pris_subs_dis==1 | pris_subs_tort==1
replace pris_subs=. if pris_subs_kill==. & pris_subs_dis==. & pris_subs_tort==.

* generate other necessary lags and transformations:
replace democ=. if democ<0
replace autoc=. if autoc<0
gen l1polity2sq=l1.polity2sq
gen l1polity2=l1.polity2
gen lnpop=ln(pop)
gen l1lnpop=l1.lnpop
gen lngdp=ln(gdp)
gen l1lngdp=l1.lngdp
gen l1priowar=l1.priowar
}

**descriptive statistics:
quietly probit F.kill_subs   shame_killing   polity2 polity2sq priowar lnpop time time2, cluster(ccode) nolog
tabstat  shame_killing shame_tort shame_disapp shame_impris if e(sample)==1, stats(mean p50 sd min max)
tabstat polity2 priowar lnpop if e(sample)==1, stats(mean p50 sd min max)


** Use binary key IVs in place of counts
probit F.kill_subs   shamekillbin   polity2 polity2sq priowar  lnpop time time2, cluster(ccode) nolog
probit F.tort_subs shametortbin  polity2  polity2sq priowar  lnpop time time2, cluster(ccode) nolog
probit F.dis_subs shamedisbin  polity2 polity2sq   priowar lnpop time time2, cluster(ccode) nolog
probit F.pris_subs shameprisbin  polity2  polity2sq   priowar lnpop time time2, cluster(ccode) nolog


*Control for GDP
probit F.kill_subs   shame_killing   polity2 polity2sq priowar  lnpop lngdp time time2, cluster(ccode) nolog
probit F.tort_subs shame_tort  polity2  polity2sq priowar  lnpop lngdp time time2, cluster(ccode) nolog
probit F.dis_subs shame_disapp  polity2 polity2sq   priowar lnpop lngdp time time2, cluster(ccode) nolog
probit F.pris_subs shame_impris  polity2  polity2sq   priowar lnpop lngdp time time2, cluster(ccode) nolog

*Control for other forms of repression?
probit F.kill_subs   shame_killing   polity2 polity2sq priowar lnpop time time2 kill tort disap polpris, cluster(ccode) nolog
probit F.tort_subs shame_tort  polity2  polity2sq priowar  lnpop time time2 kill tort disap polpris, cluster(ccode) nolog
probit F.dis_subs shame_disapp  polity2 polity2sq   priowar lnpop time time2 kill tort disap polpris, cluster(ccode) nolog
probit F.pris_subs shame_impris  polity2  polity2sq   priowar lnpop time time2 kill tort disap polpris, cluster(ccode) nolog

quietly{
/*
*For youth bulges?
probit F.kill_subs   shame_killing   polity2 polity2sq priowar lnpop time time2 ythblgtp, cluster(ccode) nolog
probit F.tort_subs shame_tort  polity2  polity2sq priowar  lnpop time time2 ythblgtp, cluster(ccode) nolog
probit F.dis_subs shame_disapp  polity2 polity2sq   priowar lnpop time time2 ythblgtp, cluster(ccode) nolog
probit F.pris_subs shame_impris  polity2  polity2sq   priowar lnpop time time2 ythblgtp, cluster(ccode) nolog
*/
}

log close



/*
probit F.kill_subs   shame_killing   polity2 polity2sq priowar lnpop time time2, cluster(ccode) nolog
probit F.tort_subs shame_tort  polity2  polity2sq priowar  lnpop time time2, cluster(ccode) nolog
probit F.dis_subs shame_disapp  polity2 polity2sq   priowar lnpop time time2, cluster(ccode) nolog
probit F.pris_subs shame_impris  polity2  polity2sq   priowar lnpop time time2, cluster(ccode) nolog

*/
